@@ -26,10 +26,12 @@ except (ImportError, ValueError):
 if sys.version_info.major == 3:
     from . dict_LaueTools import dict_Materials, dict_Stiffness
     from . import generaltools as GT
+    from . wyckpos_lauetools import testhklcond_generalrules_array
 else:
     from dict_LaueTools import dict_Materials, dict_Stiffness
     import generaltools as GT
-
+    from wyckpos_lauetools import testhklcond_generalrules_array
+    
 DEG = np.pi / 180.0
 RAD = 1 / DEG
 IDENTITYMATRIX = np.eye(3)
@@ -70,6 +72,27 @@ def isCubic(latticeparams):
 
     return Cubic
 
+def isHexagonal(latticeparams):
+    r"""
+    :param latticeparams: 6 elements list
+    :type latticeparams: iterable object with float or integers elements
+
+    :return: True or False
+    """
+    if not isinstance(latticeparams, (list, tuple, np.ndarray)):
+        raise ValueError("latticeparams is not a list of the 6 lattice parameters")
+
+    if len(latticeparams) != 6:
+        raise ValueError("latticeparams is not a list of the 6 lattice parameters")
+
+    Hexagonal = False
+    if (latticeparams[0] == latticeparams[1] and latticeparams[5] * 1.0 == 120.0):
+        Hexagonal = True
+    if latticeparams[3] * 1.0 == 120.0 or latticeparams[4] * 1.0 == 120.0:
+        raise ValueError('Unit cell is strangely defined? if it is hexagonal I would expect gamma=120degrees.\n %s'%str(latticeparams))
+
+    return Hexagonal
+
 
 def ApplyExtinctionrules(HKL, Extinc, verbose=0):
     r"""
@@ -88,8 +111,10 @@ def ApplyExtinctionrules(HKL, Extinc, verbose=0):
     if verbose:
         print("nb of reflections before extinctions %d" % len(HKL))
 
+    if Extinc.isdecimal():
+        array_hkl = testhklcond_generalrules_array(Extinc, HKL)
     # 'dia' adds selection rules to those of 'fcc'
-    if Extinc in ("fcc", "dia"):
+    elif Extinc in ("fcc", "dia"):
         cond = ((H - K) % 2 == 0) * ((H - L) % 2 == 0)
         if Extinc == "dia":
             conddia = ((H + K + L) % 4) != 2
@@ -105,7 +130,7 @@ def ApplyExtinctionrules(HKL, Extinc, verbose=0):
         cond1 = (H + K) % 2 == 0
         array_hkl = np.take(HKL, np.where(cond1 == True)[0], axis=0)
 
-    elif Extinc == "h+k+l=2n":  # group space 139 indium
+    elif Extinc == "h+k+l=2n":  # group space 139 indium also SG 82 tetragonal
         cond1 = (H + K + L) % 2 == 0
         array_hkl = np.take(HKL, np.where(cond1 == True)[0], axis=0)
 
@@ -115,6 +140,12 @@ def ApplyExtinctionrules(HKL, Extinc, verbose=0):
         cond = cond1 * cond2
         array_hkl = np.take(HKL, np.where(cond == True)[0], axis=0)
 
+    elif Extinc == "R3m_sg160":
+        cond1 = (-H + K + L) % 3 == 0
+        # cond2 = (L) % 2 == 0
+        # cond = cond1 * cond2
+        array_hkl = np.take(HKL, np.where(cond1 == True)[0], axis=0)
+
     elif Extinc == "SG166":
         cond = (-H + K + L) % 3 == 0
         array_hkl = np.take(HKL, np.where(cond == True)[0], axis=0)
@@ -1156,7 +1187,9 @@ def strain_from_crystal_to_sample_frame2(strain, UBmat, sampletilt=40.0):
     Compute strain components in sample frame:
     Zsample perpendicular to sample surface
     Xsample in the same plane thanZ and incoming vector, Xsample is tilted by sampletilt from incoming beam (XLauetools)
-    Ysample is horizontal and equal to Ylauetools
+    Ysample is horizontal and equal to Ylauetools (perpendicular to the beam)
+
+    .. warning:: on BM32 beamline xech = -Ysample   yech = Xsample  Zech = Zsample
 
     :param strain: 3x3 symmetric array describing the strain in crystal frame
     :param UBmat: 3x3 array, orientation matrix
@@ -1186,20 +1219,23 @@ def strain_from_crystal_to_sample_frame2(strain, UBmat, sampletilt=40.0):
 
     return strain_sampleframe
 
-# def strain_from_crystal_to_LaueToolsframe(strain, UBmat):
-#     r"""
-#     qxyzLT= UB B0 q_a*b*c*
 
-#     if cubic , B0 is proportional to Id, then frame transfrom matrix is UBmat
+def strain_from_crystal_to_LaueToolsframe(strain, UBmat):
+    r"""
+    to express strain in lauetools frame (x // ki, z towards detector, y // z^x)
+    
+    
+    qxyzLT= UB B0 q_a*b*c*
 
-#     Normally pure rotational part of UBmat must be considered...It should be Ok for small deformation in UBmat
+    if cubic , B0 is proportional to Id, then frame transfrom matrix is UBmat
 
-#     operator_LT= UB operator_crystal UB-1
+    Normally pure rotational part of UBmat must be considered...It should be Ok for small deformation in UBmat
 
-#     """
-#     strain_LaueToolsframe = np.dot(UBmat, np.dot(strain, np.linalg.inv(UBmat)))
+    operator_LT= UB operator_crystal UB-1
+    """
+    strain_LaueToolsframe = np.dot(UBmat, np.dot(strain, np.linalg.inv(UBmat)))
 
-#     return strain_LaueToolsframe
+    return strain_LaueToolsframe
 
 
 # def strain_from_crystal_to_sample_frame(
