@@ -342,7 +342,7 @@ def pixelvalat(imagefilename, xy=None, sortpeaks=False, CCDLabel='sCMOS'):
     :param sortpeaks: True or False, to sort peaks by increasing y value
     .. note: assume nb  of peaks > 1
     """
-    if not isinstance(xy[0,0],np.int):
+    if not isinstance(xy[0,0],np.int16):
         xy=np.int_(xy)
     if not sortpeaks: # already sorted
         xx,yy = np.array(xy).T
@@ -428,6 +428,7 @@ def getroismax(imagefilename, roicenters=None, halfboxsize=(10,10), CCDLabel='sC
                         elif counter == "Iptp_multiple":
                             CountersData["Iptp_multiple"][roi_index] = np.ptp(piece_dat_m, axis=(1, 2))
 
+                # TODO this branch is useless ?!
                 elif counter.startswith("pos"):
 
                     if 'multiple' in counter:
@@ -502,8 +503,61 @@ def getroisXYmax(imagefilename, roicenters=None, halfboxsize=(10,10), CCDLabel='
                     
 
                 elif counter.startswith("pos"):
+                    # method 2  ------ position of maximum --------
+                    datmaximumpos = scind.measurements.maximum_position(piece_dat)
+                    datmaximumpos = np.array(datmaximumpos, dtype="uint32")
 
-                    datminimum = scind.measurements.maximum(piece_dat)
+                    posmax = datmaximumpos + np.array([jmin, imin])
+
+                    # position monitors selection
+                    XY = posmax
+
+                    xDATA, yDATA = XY
+
+                    CountersData["posXY"][i_idx] = [xDATA,yDATA]
+            i_idx+=1
+    return CountersData["posXY"]
+
+def getroiscenterofmass(imagefilename, roicenters=None, halfboxsize=(10,10), CCDLabel='sCMOS'):
+    dataimage= None
+    framedim=None
+
+    selectedcounters = ["posX","posY"]
+    CountersData={}
+    CountersData["posXY"]=np.zeros((len(roicenters),2))
+    with fabio.open(imagefilename) as img:  # ok for sCMOS
+        dataimage = img.data
+        framedim = dataimage.shape
+        i_idx = 0
+        for roi_index, roi in enumerate(roicenters):
+            center_pixel = (round(roi[0]), round(roi[1]))
+
+            indicesborders = ImProc.getindices2cropArray((center_pixel[0], center_pixel[1]),
+                                                    (halfboxsize[0], halfboxsize[1]),
+                                                    framedim,
+                                                    flipxycenter=0)
+            imin, imax, jmin, jmax = indicesborders
+
+            # avoid to wrong indices when slicing the data
+            imin, imax, jmin, jmax = ImProc.check_array_indices(imin, imax + 1, jmin, jmax + 1,
+                                                                                    framedim=framedim)
+
+            piece_dat = dataimage[imin:imax, jmin:jmax]
+
+            for counter in selectedcounters:
+
+                if counter.startswith("I"):
+                    if counter == "Imean":
+                        CountersData["Imean"][roi_index] = np.mean(piece_dat)
+                    elif counter == "Imax":
+                        CountersData["Imax"][roi_index] = np.amax(piece_dat)
+                    elif counter == "Iptp":
+                        CountersData["Iptp"][roi_index] = np.ptp(piece_dat)
+                    
+
+                elif counter.startswith("pos"):
+                    # method 1  ------  center of mass  without a flat baseline-----
+                    datminimum = scind.measurements.minimum(piece_dat)
                     # center of mass without background removal
                     datcenterofmass = np.array(scind.measurements.center_of_mass(piece_dat))
                     # remove baseline level set to minimum pixel intensity
@@ -511,13 +565,6 @@ def getroisXYmax(imagefilename, roicenters=None, halfboxsize=(10,10), CCDLabel='
 
                     centerofmass = datcenterofmass2 + np.array([jmin, imin])
 
-                    datmaximumpos = scind.measurements.maximum_position(piece_dat)
-                    datmaximumpos = np.array(datmaximumpos, dtype="uint32")
-
-                    posmax = datmaximumpos + np.array([jmin, imin])
-
-                    # position monitors selection
-                    #XY = posmax
                     XY = centerofmass
 
                     xDATA, yDATA = XY
@@ -781,7 +828,7 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
     if FABIO_EXISTS:
         if CCDLabel in ('MARCCD165', "EDF", "EIGER_4M", "EIGER_1M","IMSTAR_bin2","IMSTAR_bin1",
                         "sCMOS", "sCMOS_fliplr", "sCMOS_fliplr_16M", "sCMOS_16M",
-                        "Rayonix MX170-HS", 'psl_weiwei', 'ImageStar_dia_2021','ImageStar_dia_2021_2x2'):
+                        "Rayonix MX170-HS", 'psl_weiwei', 'ImageStar_dia_2021','ImageStar_dia_2021_2x2', 'Alban'):
 
             if verbose > 1:
                 print('----> Using fabio ... to open %s\n'%filename)
@@ -1236,7 +1283,8 @@ def readoneimage_manycrops(filename, centers, boxsize, stackimageindex=-1, CCDLa
     :param boxsize: iterable 2 elements or integer
               boxsizes [in x, in y] direction or integer to set a square ROI
 
-    :return: Data, list of 2D array pixel intensity or Data and Imax
+    :return: Data, list of 2D array pixel intensity if addImax is False
+            or (Data,Imax) if addImax is True
     """
     # use alternate data  (for instance for data from filename without background)
     if use_data_corrected is not None:
@@ -1256,10 +1304,10 @@ def readoneimage_manycrops(filename, centers, boxsize, stackimageindex=-1, CCDLa
 
     # xpic, ypic = np.array(centers).T
 
-    #    x1 = np.array(np.maximum(0, xpic - boxsizex), dtype=np.int)
-    #    x2 = np.array(np.minimum(framedim[0], xpic + boxsizex), dtype=np.int)
-    #    y1 = np.array(np.maximum(0, ypic - boxsizey), dtype=np.int)
-    #    y2 = np.array(np.minimum(framedim[1], ypic + boxsizey), dtype=np.int)
+    #    x1 = np.array(np.maximum(0, xpic - boxsizex), dtype=np.int16)
+    #    x2 = np.array(np.minimum(framedim[0], xpic + boxsizex), dtype=np.int16)
+    #    y1 = np.array(np.maximum(0, ypic - boxsizey), dtype=np.int16)
+    #    y2 = np.array(np.minimum(framedim[1], ypic + boxsizey), dtype=np.int16)
 
     Data = []
 
