@@ -26,10 +26,15 @@ except ModuleNotFoundError:
 
 class SpecFile:
     """
-    Simple class to read SPEC file. The main purposes are :
+    Simple class to read SPEC file or BLISS hdf5 file. The main purposes are :
     (i) read the header and initiate the relevant properties
     (ii) build a dictionary of the scan number and their binary position in the file
     The latter allows for faster subsequent scan reading
+    :param filetype: str, 'spec' or 'hdf5'
+    :param collectallscans: bool, True, collect all scans
+    :param onlywirescan: bool, True, collect only wire scan, ie ascan of zf or yf motor
+    :param onlymesh: bool, True, collect only amesh scan (ie 2D scan)
+    
     Definition:
     -----------
     SpecFile(spec_file, verbose = False)
@@ -187,9 +192,10 @@ class SpecFile:
         elif filetype == 'hdf5':
             selp, allp = getscans_from_hdf5file(spec_file, collectallscans=self.collectallscans,
                                                             onlywirescan=self.onlywirescan, onlymesh=self.onlymesh,
-                                                            verbose=0)
+                                                            verbose=verbose)
             self.scan_dict = self.get_scandict(selp)
             self.cmd_list = self.get_cmd_list(selp)
+            #self.filetype ='hdf5'
 
 
     def get_cmd_list(self, listprops):
@@ -209,7 +215,21 @@ class SpecFile:
         """ return date of file corresponding to listprops (generated by getwirescan_from_hdf5file)"""
         return listprops[0][3]
 
+# helper function of listprops generated by getwirescan_from_hdf5file
+def get_cmd_list(listprops):
+    """ return dict of commands in the list (generated by getwirescan_from_hdf5file)"""
+    return { elem[0]: elem[4] for elem in listprops}
+def get_scandict(listprops):
+    """ return dict of keys ... (only to fit the previous spec-related interface)
+    (generated by getwirescan_from_hdf5file)"""
+    return { elem[0]: elem[0] for elem in listprops}
+def get_file(listprops):
+    """ return master file corresponding to listprops (generated by getwirescan_from_hdf5file)"""
+    return listprops[0][-1]
 
+def get_date(listprops):
+    """ return date of file corresponding to listprops (generated by getwirescan_from_hdf5file)"""
+    return listprops[0][3]
 class Scan(SpecFile):
     """
     Simple class to read extract scans from SPEC files. All the parameters of the scan and the data are read
@@ -395,7 +415,7 @@ class Scan(SpecFile):
 
 class Scan_hdf5(SpecFile):
     """
-    Simple class to read extract scans from bliss files. All the parameters of the scan and the data are read
+    Simple class to read extract single scan from bliss files. All the parameters of the scan and the data are read
     and stored as attributes.
 
     Definition:
@@ -452,19 +472,19 @@ class Scan_hdf5(SpecFile):
 
     author: J.S. Micha
     """
-    def __init__(self, spec_file, scan_keys,collectallscans=True, onlywirescan=False,
+    def __init__(self, spec_file, scan_key, collectallscans=True, onlywirescan=False,
                                                                 onlymesh=False,
                                                                 verbose=False):
 
         if type(spec_file) == str:
             spec_file = SpecFile(spec_file, filetype='hdf5')
         self.file = spec_file.file
-        
-        try:  # WARNING single key for the moment
-            len_scan_number = len(scan_keys)  # it is a list of scan
-        except TypeError:
-            scan_keys = [scan_keys, ]  # it is a simple scan, we make a len 0 list
-        scan_number = scan_keys[0]  # for all intents and purposes
+
+        ###  WARNING: single key for the moment!
+        if isinstance(scan_key,str):
+            scan_number = scan_key
+        elif isinstance(scan_key,list):
+            scan_number = scan_key[0]
 
         # recover the names of the motors from the header of the SPEC file (i.e. the SpecFile instance)
         self.__motorslabels__ = spec_file.__motorslabels__  # list of all motors in the experiment
@@ -472,13 +492,13 @@ class Scan_hdf5(SpecFile):
         # prepare the scan-specific attributes
         self.__positions__ = ""  # list the values of all motors
         self.__config__ = ""  # list the values of the UB matrix config
-        self.scan_keys = scan_keys
+        self.scan_key = scan_key
         
         self.comments = ""
 
         #print('beginning of __init__ of scan_hdf5')
         selp, _ = getscans_from_hdf5file(spec_file.file)
-        tit, data, posmotors, fullpath, scan_date = readdata_from_hdf5key(selp, scan_keys, outputdate=True)
+        tit, data, posmotors, fullpath, scan_date = readdata_from_hdf5key(selp, scan_key, outputdate=True)
 
         if verbose:
             print('tit',tit)
@@ -493,7 +513,7 @@ class Scan_hdf5(SpecFile):
 
         self.fullpath = fullpath
         
-        scanindex= int(scan_keys.rsplit('_',1)[-1])
+        scanindex= int(scan_key.rsplit('_',1)[-1])
         basepath = os.path.split(fullpath)[0]
         self.scanfolder = os.path.join(basepath, 'scan_%04d'%scanindex)
         self.motors = posmotors
